petl - Extract, Transform and Load
===================================================

``petl`` is a general purpose Python package for extracting, transforming and
loading tables of data.

.. image:: docs/petl-architecture.png
    :align: center
    :alt: petl architecture example

Resources
---------

- Documentation: http://petl.readthedocs.org/
- Mailing List: http://groups.google.com/group/python-etl
- PyPI: http://pypi.python.org/pypi/petl
- Conda Forge:https://anaconda.org/conda-forge/petl

DevOps Status
-------------

.. image:: https://github.com/petl-developers/petl/actions/workflows/test-changes.yml/badge.svg
    :target: https://github.com/petl-developers/petl/actions/workflows/test-changes.yml
    :alt: Continuous Integration build status

.. image:: https://github.com/petl-developers/petl/actions/workflows/publish-release.yml/badge.svg
    :target: https://github.com/petl-developers/petl/actions/workflows/publish-release.yml
    :alt: PyPI release status

.. image:: https://github.com/conda-forge/petl-feedstock/actions/workflows/automerge.yml/badge.svg
    :target: https://github.com/conda-forge/petl-feedstock/actions/workflows/automerge.yml
    :alt: Conda Forge release status

.. image:: https://readthedocs.org/projects/petl/badge/?version=stable
    :target: http://petl.readthedocs.io/en/stable/?badge=stable
    :alt: readthedocs.org release status

.. image:: https://coveralls.io/repos/github/petl-developers/petl/badge.svg?branch=master
    :target: https://coveralls.io/github/petl-developers/petl?branch=master
    :alt: Coveralls release status

.. image:: https://zenodo.org/badge/2233194.svg
   :target: https://zenodo.org/badge/latestdoi/2233194
